@@ -40,7 +40,5 @@ class WrapAspell
 		AspellConfig *spell_config;
 		AspellSpeller *spell_checker;
 		bool checkWord ( char *s, size_t len );
-		char *getWord ( char **s, size_t *len );
-		inline bool isWordCharacter ( char *s, size_t *bytes );
 };
 #endif
