@@ -25,7 +25,7 @@
 
 #endif
 #define ABOUT_COPYRIGHT _("Copyright © 2005-2008 Gerald Schmidt <gnschmidt@users.sourceforge.net>")
-#define ABOUT_DESCRIPTION _("\nXML Copy Editor is free software released under the GNU\nGeneral Public License.\n\nMany thanks are due to Tim van Niekerk, Matt Smigielski,\nDavid Scholl, Jan Merka, Marcus Bingenheimer, Roberto\nRosselli Del Turco, Ken Zalewski, C.J. Meidlinger,\nThomas Zajic, Viliam Búr, David Håsäther, François\nBadier, Thomas Wenzel, Roger Sperberg, SHiNE CsyFeK,\nHSU PICHAN, YANG SHUFUN, CHENG PAULIAN,\nCHUANG KUO-PING, Justin Dearing, Serhij Dubyk,\nAntonio Angelo, Jose Luis Rivero and Siarhei Kuchuk.")
+#define ABOUT_DESCRIPTION _("\nXML Copy Editor is free software released under the GNU\nGeneral Public License.\n\nMany thanks are due to Tim van Niekerk, Matt Smigielski,\nDavid Scholl, Jan Merka, Marcus Bingenheimer, Roberto\nRosselli Del Turco, Ken Zalewski, C.J. Meidlinger,\nThomas Zajic, Viliam Búr, David Håsäther, François\nBadier, Thomas Wenzel, Roger Sperberg, SHiNE CsyFeK,\nHSU PICHAN, YANG SHUFUN, CHENG PAULIAN,\nCHUANG KUO-PING, Justin Dearing, Serhij Dubyk,\nAntonio Angelo, Jose Luis Rivero, Siarhei Kuchuk\nand Ian Abbott.")
 #define ABOUT_LICENSE _T(\
 "This program is free software; you can redistribute it\n"\
 "and/or modify it under the terms of the GNU General Public\n"\
@@ -41,5 +41,5 @@
 "License along with this program; if not, write to the Free\n"\
 "Software Foundation, Inc., 59 Temple Place, Suite 330,\n"\
 "Boston, MA 02111-1307 USA.")
-#define ABOUT_VERSION _T("1.1.0.7")
+#define ABOUT_VERSION _T("1.2.0")
 #define XMLCE_VAR _T("XMLCE_VAR")
