@@ -21,7 +21,10 @@
 #include "xmlpromptgenerator.h"
 #include "xmlshallowvalidator.h"
 #include "xmlencodinghandler.h"
+#include "wrapxerces.h"
+#include "xmlcopyeditor.h" // needed to enable validation-as-you-type alerts
 #include <utility>
+#include <memory>
 
 // adapted from wxSTEdit (c) 2005 John Labenski, Otto Wyss
 #define XMLCTRL_HASBIT(value, bit) (((value) & (bit)) != 0)
@@ -37,6 +40,9 @@ BEGIN_EVENT_TABLE ( XmlCtrl, wxStyledTextCtrl )
 	EVT_MIDDLE_DOWN ( XmlCtrl::OnMiddleDown )
 END_EVENT_TABLE()
 
+// global protection for validation threads
+wxCriticalSection xmlcopyeditorCriticalSection;
+
 XmlCtrl::XmlCtrl (
     wxWindow *parent,
     XmlCtrlProperties propertiesParameter,
@@ -59,8 +65,16 @@ XmlCtrl::XmlCtrl (
 		basePath ( basePathParameter ),
 		auxPath ( auxPathParameter )
 {
+	validationThread = NULL;
+	validationStarted = false;
+	validationFinished = false;
+	grammarFound = false;
+	validationRequired = (buffer) ? true : false; // NULL for plain XML template
+
+	validationReleasePtr = new bool;
+	*validationReleasePtr = false;
+	
 	currentMaxLine = 1;
-	validationRequired = grammarFound = false;
 
 	applyProperties ( propertiesParameter );
 
@@ -110,6 +124,28 @@ XmlCtrl::XmlCtrl (
 	IndicatorSetForeground ( 0, *wxRED );
 }
 
+
+XmlCtrl::~XmlCtrl()
+{
+	attributeMap.clear();
+	elementMap.clear();
+	entitySet.clear();
+
+	if ( validationStarted && !validationFinished )
+	{
+		*validationReleasePtr = true;
+
+		// don't delete validationReleasePtr because the thread will check the value before exiting
+		// this means that 1 variable of type bool will be leaked in this case
+		// the alternative is waiting for the validation thread to finish, which can take anything up to several minutes
+		return;
+	}
+	
+	delete validationReleasePtr;
+		
+}
+
+
 // taken from wxStyledNotebook (c) Eran Ifrah <eranif@bezeqint.net>
 static wxColor LightColour ( const wxColour& color, int percent )
 {
@@ -131,7 +167,29 @@ static wxColor LightColour ( const wxColour& color, int percent )
 void XmlCtrl::OnIdle ( wxIdleEvent& event )
 {
 	if ( properties.number && type != FILE_TYPE_BINARY )
-		adjustNoColumnWidth();
+		adjustNoColumnWidth(); // exits if unchanged
+
+	// poll validation thread output if any
+	
+	{
+		wxCriticalSectionLocker locker ( xmlcopyeditorCriticalSection );
+		if (validationStarted && validationFinished)
+		{
+			validationStarted = false;
+			MyFrame *frame = (MyFrame *)GetGrandParent();
+			if ( validationSuccess )
+			{
+				clearErrorIndicators ( GetLineCount() );
+				frame->statusProgress ( wxEmptyString );
+			}
+			else
+			{
+				clearErrorIndicators ( GetLineCount() );
+				setErrorIndicator ( validationPosition.first - 1, 0 );
+				frame->statusProgress ( wxString ( validationMessage.c_str(), wxConvUTF8, validationMessage.size() ) );
+			}
+		}
+	}
 }
 
 void XmlCtrl::OnChar ( wxKeyEvent& event )
@@ -419,14 +477,14 @@ void XmlCtrl::handleOpenAngleBracket ( wxKeyEvent& event )
 	if ( AutoCompActive() )
 		AutoCompCancel();
 
+	validationRequired = true;
+
 	if ( *protectTags )
 	{
 		AddText ( _T ( "&lt;" ) );
 		return;
 	}
 
-	validationRequired = true;
-
 	AddText ( _T ( "<" ) );
 
 	int pos = GetCurrentPos();
@@ -477,14 +535,14 @@ void XmlCtrl::handleCloseAngleBracket ( wxKeyEvent& event )
 	if ( AutoCompActive() )
 		AutoCompCancel();
 
+	validationRequired = true;
+
 	if ( *protectTags )
 	{
 		AddText ( _T ( "&gt;" ) );
 		return;
 	}
-
-	validationRequired = true;
-
+	
 	wxString insertBuffer;
 	int pos;
 	pos = GetCurrentPos();
@@ -663,7 +721,10 @@ void XmlCtrl::handleSpace ( wxKeyEvent& event )
 		choice.Append ( conversion );
 	}
 	if ( !choice.empty() )
+	{
 		UserListShow ( 0, choice );
+		validationRequired = true;
+	}
 }
 
 void XmlCtrl::handleAmpersand ( wxKeyEvent& event )
@@ -731,6 +792,7 @@ void XmlCtrl::handleForwardSlash ( wxKeyEvent& event )
 	if ( wideParent.empty() )
 		return;
 	AddText ( wideParent + _T ( ">" ) );
+	validationRequired = true;
 }
 
 void XmlCtrl::OnKeyPressed ( wxKeyEvent& event )
@@ -842,6 +904,7 @@ void XmlCtrl::OnKeyPressed ( wxKeyEvent& event )
 			break;
 		case WXK_BACK:
 			handleBackspace ( event );
+			validationRequired = true;
 			return;
 		case WXK_TAB:
 			if ( *protectTags )
@@ -888,6 +951,7 @@ void XmlCtrl::OnKeyPressed ( wxKeyEvent& event )
 			break;
 		case WXK_DELETE:
 			handleDelete ( event );
+			validationRequired = true;
 			return;
 		default:
 			break;
@@ -1015,7 +1079,7 @@ int XmlCtrl::getParentCloseAngleBracket ( int pos, int range )
 }
 
 void XmlCtrl::adjustNoColumnWidth()
-{
+{	
 	int maxLine = GetLineCount();
 	if ( maxLine == currentMaxLine )
 		return;
@@ -1963,126 +2027,57 @@ std::string XmlCtrl::getElementStructure ( const wxString& element )
 	return ret;
 }
 
-bool XmlCtrl::shallowValidate ( int maxLine, bool segmentOnly )
+bool XmlCtrl::backgroundValidate()
 {
 	if ( !properties.validateAsYouType || type != FILE_TYPE_XML )
 		return true;
 
-	validationRequired = false;
-
-	if ( !maxLine )
-		maxLine = GetLineCount();
-
-	std::string bufferUtf8;
-	int startLine, columnOffset;
-	startLine = columnOffset = 0;
-
-	if ( !segmentOnly )
-	{
-		clearErrorIndicators ( maxLine );
-		bufferUtf8 = myGetTextRaw();
-	}
-	else
-	{
-		int current,
-		line,
-		lineEnd,
-		parentCloseAngleBracket,
-		parentStartAngleBracket,
-		memory;
-		current = GetCurrentPos();
-		line = LineFromPosition ( current );
-
-		// try to include next line
-		lineEnd = GetLineEndPosition ( line + 1 );
-		if ( lineEnd == -1 )
-			lineEnd = GetLineEndPosition ( line );
-
-		// fetch parent
-		parentCloseAngleBracket = getParentCloseAngleBracket ( current );
-		parentStartAngleBracket = getTagStartPos ( parentCloseAngleBracket );
-		if ( parentStartAngleBracket == -1 )
-			return false;
-
-		memory = parentStartAngleBracket;
-
-		// fetch grandparent if not at start of document
-		if ( parentStartAngleBracket > 1 )
-		{
-			parentCloseAngleBracket =
-			    getParentCloseAngleBracket ( parentStartAngleBracket - 1 );
-			parentStartAngleBracket = getTagStartPos ( parentCloseAngleBracket );
-			if ( parentStartAngleBracket == -1 )
-				parentStartAngleBracket = memory;
-		}
-
-		startLine = LineFromPosition ( parentStartAngleBracket );
-
-		if ( startLine == line )
-		{
-			columnOffset = parentStartAngleBracket - PositionFromLine ( line );
-
-			// disallow negative offsets
-			if ( columnOffset < 0 )
-				columnOffset = 0;
-		}
-
-		// sanity-check range
-		if ( lineEnd <= parentStartAngleBracket )
-			return false;
-
-		// clear indicators within range
-		StartStyling ( parentStartAngleBracket, wxSTC_INDIC2_MASK );
-		int length = lineEnd - parentStartAngleBracket;
-		SetStyling ( length, 0 );
-
-		// tweak raw getTextRange variant
-		wxString wideBuffer = GetTextRange ( parentStartAngleBracket, lineEnd );
-
-		bufferUtf8 = ( const char * ) wideBuffer.mb_str ( wxConvUTF8 );
-	}
-
-	return shallowValidate ( bufferUtf8.c_str(), bufferUtf8.size(), startLine,
-	                         maxLine, columnOffset, segmentOnly );
+	std::string bufferUtf8 = myGetTextRaw();
+	
+	return backgroundValidate (
+		bufferUtf8.c_str(),
+		basePath.c_str(),
+		bufferUtf8.size() );
 }
 
-bool XmlCtrl::shallowValidate ( const char *buffer,
-                                size_t bufferLen,
-                                int startLine,
-                                int maxLine,
-                                int columnOffset,
-                                bool segmentOnly )
+bool XmlCtrl::backgroundValidate (
+				const char *buffer,
+				const char *system,
+                                size_t bufferLen
+				)
 {
-	std::auto_ptr<XmlShallowValidator> validator ( new XmlShallowValidator (
-	            elementMap,
-	            attributeMap,
-	            requiredAttributeMap,
-	            entitySet,
-	            maxLine,
-	            segmentOnly ) );
-
-	bool res = validator->parse ( buffer, bufferLen, ( segmentOnly ) ? false : true );
-	if (
-		!validator->getOverrideFailure() &&
-		( !res || !validator->isValid() ) )
+	if ( !validationRequired )
+		return true;
+	
+	wxCriticalSectionLocker locker ( xmlcopyeditorCriticalSection );
+	if ( validationStarted && !validationFinished )
 	{
-		std::vector<std::pair<int, int> > positionVector = validator->getPositionVector();
+		*validationReleasePtr = true;
+		return true; // wait for next idle cycle call from main app frame
+	}
+	validationRequired = false;
+	
+	*validationReleasePtr = false;
+	validationThread = new ValidationThread(
+		buffer,
+		system,
+		&validationFinished,
+		&validationSuccess,
+		validationReleasePtr,
+		&validationPosition,
+		&validationMessage
+	);
 
-		if ( res == XML_STATUS_ERROR )
-		{
-			positionVector.push_back ( validator->getErrorPosition() );
-		}
-
-		std::vector<std::pair<int, int> >::iterator it;
-		for ( it = positionVector.begin(); it != positionVector.end(); it++ )
-		{
-			int line, column;
-			line = ( it->first - 1 ) + startLine;
-			column = it->second + columnOffset;
-			setErrorIndicator ( line, column );
-		}
+	if ( validationThread->Create() != wxTHREAD_NO_ERROR )
+	{
+		validationStarted = false;
+		validationFinished = true;
 		return false;
 	}
+	
+	validationStarted = true;
+	validationFinished = false;
+	validationThread->Run();
 	return true;
 }
 
@@ -2106,12 +2101,6 @@ void XmlCtrl::setErrorIndicator ( int line, int column )
 
 	int length = endPos - startPos;
 
-	/*
-	from CellBuffer.cxx:
-	 PLATFORM_ASSERT(lengthStyle == 0 ||
-		(lengthStyle > 0 && lengthStyle + position < length));
-	*/
-
 	if ( length == 0 || ( length > 0 && length + startPos < GetLength() ) )
 	{
 		SetStyling ( length, wxSTC_INDIC2_MASK );
